# Harpoon Tools

CLI tools using [Harpoon](https://github.com/Te-k/harpoon) features

## Tools

* **ipinfo** : provides information on an IP address (ASN and location)
* **asninfo** : provides information on an ASN number
* **dns** : provides DNS information on a domain or IP
* **asncount** : count IP addresses by ASN numbers
* **countrycount** : count IP addresses by countries
* **htraceroute**: traceroute adding AS and geolocation of IPs (you need to have traceroute installed)
* **myip**: get your public IP and location from ipinfo.io

## Install

Install [Harpoon](https://github.com/Te-k/harpoon) and then harpoontools :

```
pip install harpoon
pip install harpoontools
```

Configure Harpoon and download static files:
```
harpoon config -u
harpoon config
```

## Licence

This code is licensed under GPLv3
